@@ -2,6 +2,7 @@
   This file is part of Lokalize
 
   Copyright (C) 2007-2014 by Nick Shaforostoff <shafff@ukr.net>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -140,7 +141,7 @@ void MsgCtxtView::process()
 
     QString html;
     foreach (const Note& note, m_catalog->developerNotes(m_entry.toDocPosition())) {
-        html += MsgCtxtView::BR + escapeWithLinks(note.content);
+        html += MsgCtxtView::BR + escapeWithLinks(note.content).replace('\n', BR);
     }
 
     QStringList sourceFiles = m_catalog->sourceFiles(m_entry.toDocPosition());
